@@ -43,7 +43,7 @@ class MirrorDelegate : public QStyledItemDelegate
         QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
     private:
-        QSortFilterProxyModel *m_countrySort;
+        QSortFilterProxyModel *m_countrySort = nullptr;
 };
 
 class MirrorProxyModel : public QSortFilterProxyModel
@@ -51,7 +51,7 @@ class MirrorProxyModel : public QSortFilterProxyModel
     Q_OBJECT
 
     public:
-        MirrorProxyModel(QObject *parent = 0);
+        MirrorProxyModel(QObject *parent = nullptr);
 
     protected:
         bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
